# abvelocity

> **⚠ Alpha — early development.**
>
> This library is in active early development. It is **not yet ready for
> production use** and comes with **no warranty** — use at your own discretion.
> **Estimated Beta release timeline: ~September 2026.**
>
> Bug reports via GitHub issues are welcome. Fixes may take time at this early stage.

A library to increase experimentation velocity.
The main current supported tooling is called "Multi-Experiment Analysis (MEA)".

MEA allows us to analyze multiple concurrent orthogonal experiments.


See [What is MEA?](./docs/docs/content/2-what-is-mea.md)

See [Run MEA (Generic Version)](./docs/docs/content/4-run-mea-generic.md)

See [MEA Report](./docs/docs/content/5-mea-report.md)
